@@ -11,8 +11,8 @@
 #ifndef _BONOBO_WIDGET_H_
 #define _BONOBO_WIDGET_H_
 
-#include <glib/gmacros.h>
-#include <gtk/gtkbin.h>
+#include <glib.h>
+#include <gtk/gtk.h>
 #include <bonobo/Bonobo.h>
 #include <bonobo/bonobo-object.h>
 
@@ -84,10 +84,10 @@ BonoboWidget       *bonobo_widget_construct_control             (BonoboWidget
  */
 void                 bonobo_widget_set_property             (BonoboWidget       *control,
 							     const char         *first_prop,
-							     ...);
+							     ...) G_GNUC_NULL_TERMINATED;
 void                 bonobo_widget_get_property             (BonoboWidget       *control,
 							     const char         *first_prop,
-							     ...);
+							     ...) G_GNUC_NULL_TERMINATED;
 
 /* Compat */
 #define bonobo_widget_get_uih(w) bonobo_widget_get_ui_container (w)
